# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.dataproc.manager.v1 import job_service_pb2 as yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2


class JobServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListActive = channel.unary_unary(
        '/yandex.cloud.dataproc.manager.v1.JobService/ListActive',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
        )
    self.UpdateStatus = channel.unary_unary(
        '/yandex.cloud.dataproc.manager.v1.JobService/UpdateStatus',
        request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
        )


class JobServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ListActive(self, request, context):
    """Retrieves a list of jobs for Data Proc cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateStatus(self, request, context):
    """Currently used to update Job status.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListActive': grpc.unary_unary_rpc_method_handler(
          servicer.ListActive,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.SerializeToString,
      ),
      'UpdateStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateStatus,
          request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.dataproc.manager.v1.JobService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
