# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import node_group_service_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class NodeGroupServiceStub(object):
  """A set of methods for managing node groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Get',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.GetNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2.NodeGroup.FromString,
        )
    self.List = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/List',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsResponse.FromString,
        )
    self.Create = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Create',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.CreateNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Update = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Update',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.UpdateNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.Delete = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/Delete',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.DeleteNodeGroupRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
        )
    self.ListOperations = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/ListOperations',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsResponse.FromString,
        )
    self.ListNodes = channel.unary_unary(
        '/yandex.cloud.k8s.v1.NodeGroupService/ListNodes',
        request_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesRequest.SerializeToString,
        response_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesResponse.FromString,
        )


class NodeGroupServiceServicer(object):
  """A set of methods for managing node groups.
  """

  def Get(self, request, context):
    """Returns the specified node group.

    To get the list of available node group, make a [List] request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """Retrieves the list of node group in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    """Creates a node group in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Updates the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Deletes the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListOperations(self, request, context):
    """Lists operations for the specified node group.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListNodes(self, request, context):
    """Retrieves the list of nodes in the specified Kubernetes cluster.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodeGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.GetNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2.NodeGroup.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupsResponse.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.CreateNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.UpdateNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.DeleteNodeGroupRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
      ),
      'ListOperations': grpc.unary_unary_rpc_method_handler(
          servicer.ListOperations,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupOperationsResponse.SerializeToString,
      ),
      'ListNodes': grpc.unary_unary_rpc_method_handler(
          servicer.ListNodes,
          request_deserializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesRequest.FromString,
          response_serializer=yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__service__pb2.ListNodeGroupNodesResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'yandex.cloud.k8s.v1.NodeGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
